#include <iostream>
#include <string>
#include <cmath>
using namespace std;

class Character
{
protected:
  string name;
  int level;
  int exp;
  int power;
  int knowledge;
  int luck;
  static const int expForLevel = 100;
  void levelUp(int pInc, int kInc, int lInc);
public:
  Character(string n, int lv, int po, int kn, int lu);
  void beatMonster(int exp);
  void print();
  string getName();
};

Character::Character(string n, int lv, int po, int kn, int lu) 
  : name(n), level(lv), exp(pow(lv - 1, 2) * expForLevel), power(po), knowledge(kn), luck(lu) 
{
}

void Character::beatMonster(int exp)
{
  this->exp += exp;
  if(this->exp >= pow(this->level, 2) * expForLevel)
  	this->levelUp(0, 0, 0);
}

void Character::print()
{
  cout << this->name 
       << ": Level " << this->level << " (" << this->exp << "/" << pow(this->level, 2) * expForLevel
       << "), " << this->power << "-" << this->knowledge << "-" << this->luck << "\n";
}

void Character::levelUp(int pInc, int kInc, int lInc)
{
  this->level++;
  this->power += pInc;
  this->knowledge += kInc;
  this->luck += lInc;    
}

string Character::getName()
{
  return this->name;
}





class Warrior : public Character
{
private:
  static const int powerPerLevel = 10;
  static const int knowledgePerLevel = 5;
  static const int luckPerLevel = 5;
public:
  Warrior(string n) : Character(n, 1, powerPerLevel, knowledgePerLevel, luckPerLevel) {}
  Warrior(string n, int lv) : Character(n, lv, lv * powerPerLevel, lv * knowledgePerLevel, lv * luckPerLevel) {}
  void print()
  {
    cout << "Warrior ";
    Character::print();
  }  
  void beatMonster(int exp)
  {
  	this->exp += exp;
  	if(this->exp >= pow(this->level, 2) * expForLevel)
  	  this->levelUp(powerPerLevel, knowledgePerLevel, luckPerLevel);
  }
};

class Wizard : public Character
{
private:
  static const int powerPerLevel = 4;
  static const int knowledgePerLevel = 9;
  static const int luckPerLevel = 7;
public:
  Wizard(string n) : Character(n, 1, powerPerLevel, knowledgePerLevel, luckPerLevel) {}
  Wizard(string n, int lv) : Character(n, lv, lv * powerPerLevel, lv * knowledgePerLevel, lv * luckPerLevel) {}
  void print()
  {
    cout << "Wizard ";
    Character::print();
  }  
  void beatMonster(int exp)
  {
  	this->exp += exp;
  	if(this->exp >= pow(this->level, 2) * expForLevel)
  	  this->levelUp(powerPerLevel, knowledgePerLevel, luckPerLevel);
  }
};












class Team
{
private:
  int warriorCount;
  int wizardCount;
  Warrior* warrior[10];
  Wizard* wizard[10];
public:
  Team();
  ~Team();
  void addWarrior(string name, int lv);
  void addWizard(string name, int lv);
  void warriorBeatMonster(string name, int exp);
  void wizardBeatMonster(string name, int exp);
  void printWarrior(string name);
  void printWizard(string name);
};

Team::Team()
{
  this->warriorCount = 0;
  this->wizardCount = 0;
  for(int i = 0; i < 10; i++)
    warrior[i] = NULL;
  for(int i = 0; i < 10; i++)
    wizard[i] = NULL;
}

Team::~Team()
{
  for(int i = 0; i < this->warriorCount; i++)
    delete this->warrior[i];
  for(int i = 0; i < this->wizardCount; i++)
    delete this->wizard[i];
}

void Team::addWarrior(string name, int lv)
{
  if(this->warriorCount < 10)
  {
    this->warrior[this->warriorCount] = new Warrior(name, lv);
    this->warriorCount++;
  }
}

void Team::addWizard(string name, int lv)
{
  if(this->wizardCount < 10)
  {
    this->wizard[this->wizardCount] = new Wizard(name, lv);
    this->wizardCount++;
  }
}

void Team::warriorBeatMonster(string name, int exp)
{
  for(int i = 0; i < this->warriorCount; i++)
  {
    if(this->warrior[i]->getName() == name)
    {
      this->warrior[i]->beatMonster(exp);
      break;
    }
  }  
}

void Team::wizardBeatMonster(string name, int exp)
{
  for(int i = 0; i < this->wizardCount; i++)
  {
    if(this->wizard[i]->getName() == name)
    {
      this->wizard[i]->beatMonster(exp);
      break;
    }
  }  
}

void Team::printWarrior(string name)
{
  for(int i = 0; i < this->warriorCount; i++)
  {
    if(this->warrior[i]->getName() == name)
    {
      this->warrior[i]->print();
      break;
    }
  }
}

void Team::printWizard(string name)
{
  for(int i = 0; i < this->wizardCount; i++)
  {
    if(this->wizard[i]->getName() == name)
    {
      this->wizard[i]->print();
      break;
    }
  }
}

















int main()
{
  Team t;
  char eventType = 0;
  while(cin >> eventType)
  {
    string name = "";
    int lv = 0;
    char occupation = 0;
    int exp = 0;
      
  	switch(eventType)
  	{
      case 'R':
        cin >> name;
        cin >> lv;
        t.addWarrior(name, lv);
        break;
      case 'D':
        cin >> name;
        cin >> lv;
        t.addWizard(name, lv);
        break;
      case 'B':
      	cin >> occupation;
        cin >> name;
        cin >> exp;
        if(occupation == 'R')
          t.warriorBeatMonster(name, exp);
        else if(occupation == 'D')
          t.wizardBeatMonster(name, exp);
        break;
      case 'P':
      	cin >> occupation;
        cin >> name;
        if(occupation == 'R')
          t.printWarrior(name);
        else if(occupation == 'D')
          t.printWizard(name);
        break;
  	}  		
  }

  return 0;
}














